package nl.dancingbear.tunit;

import java.io.InputStream;
import java.io.OutputStream;

/**
 * The StreamDirector redirects the input from an Inputstream to an OutputStream.
 * It continuously listens for available input and writes it to the OutputStream.
 *
 * @author Bas Basten
 * @author Anton Lycklama a Nijeholt
 * @date 06-03-2007
 */
public class StreamRedirector implements Runnable {

    private InputStream source;
    private OutputStream destination;

    /**
     * Constructor.
     *
     * @param source inputStream to listen and read from.
     * @param destination outputStream to redirect to.
     * @author Bas Basten
     * @author Anton Lycklama a Nijeholt
     * @date 06-03-2007
     */
    public StreamRedirector(InputStream source, OutputStream destination) {
        this.source = source;
        this.destination = destination;
    }

    /**
     * Start the redirecting.
     *
     * @author Bas Basten
     * @author Anton Lycklama a Nijeholt
     * @date 06-03-2007
     */
    public void run() {
        while (true) {
            try {
                int bytesAvailable = this.source.available();
                if (bytesAvailable > 0) {
                    byte[] buffer = new byte[bytesAvailable];
                    int bytesRead = this.source.read(buffer, 0, bytesAvailable);
                    if (bytesRead > 0) {
                        this.destination.write(buffer, 0, bytesRead);
                    }
                }
            }
            catch (Exception e) {
                // We have no influence when the toolbus process exits.
                // We don't have to catch the exception because we know that
                // the catch will only be called whenever the source isn't available
                // anymore.
            }
        }
    }
}
